pub struct AllocatedNum<Scalar: PrimeField> { /* private fields */ }Implementations
Sourceimpl<Scalar: PrimeField> AllocatedNum<Scalar>
impl<Scalar: PrimeField> AllocatedNum<Scalar>
Sourcepub fn alloc<CS, F>(cs: CS, value: F) -> Result<Self, SynthesisError>
pub fn alloc<CS, F>(cs: CS, value: F) -> Result<Self, SynthesisError>
Allocate a Variable(Aux) in a ConstraintSystem.
Sourcepub fn alloc_infallible<CS, F>(cs: CS, value: F) -> Selfwhere
CS: ConstraintSystem<Scalar>,
F: FnOnce() -> Scalar,
pub fn alloc_infallible<CS, F>(cs: CS, value: F) -> Selfwhere
CS: ConstraintSystem<Scalar>,
F: FnOnce() -> Scalar,
Allocate a Variable(Aux) in a ConstraintSystem. Requires an
infallible getter for the value.
Sourcepub fn alloc_input<CS, F>(cs: CS, value: F) -> Result<Self, SynthesisError>
pub fn alloc_input<CS, F>(cs: CS, value: F) -> Result<Self, SynthesisError>
Allocate a Variable(Input) in a ConstraintSystem.
Sourcepub fn alloc_maybe_input<CS, F>(
cs: CS,
is_input: bool,
value: F,
) -> Result<Self, SynthesisError>
pub fn alloc_maybe_input<CS, F>( cs: CS, is_input: bool, value: F, ) -> Result<Self, SynthesisError>
Allocate a Variable of either Aux or Input in a
ConstraintSystem. The Variable is a an Input if is_input is
true. This allows uniform creation of circuits containing components
which may or may not be public inputs.
pub fn inputize<CS>(&self, cs: CS) -> Result<(), SynthesisError>where
CS: ConstraintSystem<Scalar>,
Sourcepub fn to_bits_le_strict<CS>(
&self,
cs: CS,
) -> Result<Vec<Boolean>, SynthesisError>where
CS: ConstraintSystem<Scalar>,
Scalar: PrimeFieldBits,
pub fn to_bits_le_strict<CS>(
&self,
cs: CS,
) -> Result<Vec<Boolean>, SynthesisError>where
CS: ConstraintSystem<Scalar>,
Scalar: PrimeFieldBits,
Deconstructs this allocated number into its boolean representation in little-endian bit order, requiring that the representation strictly exists “in the field” (i.e., a congruency is not allowed.)
Sourcepub fn to_bits_le<CS>(&self, cs: CS) -> Result<Vec<Boolean>, SynthesisError>where
CS: ConstraintSystem<Scalar>,
Scalar: PrimeFieldBits,
pub fn to_bits_le<CS>(&self, cs: CS) -> Result<Vec<Boolean>, SynthesisError>where
CS: ConstraintSystem<Scalar>,
Scalar: PrimeFieldBits,
Convert the allocated number into its little-endian representation. Note that this does not strongly enforce that the commitment is “in the field.”
pub fn add<CS>(&self, cs: CS, other: &Self) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn mul<CS>(&self, cs: CS, other: &Self) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn square<CS>(&self, cs: CS) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn assert_nonzero<CS>(&self, cs: CS) -> Result<(), SynthesisError>where
CS: ConstraintSystem<Scalar>,
Sourcepub fn conditionally_reverse<CS>(
cs: CS,
a: &Self,
b: &Self,
condition: &Boolean,
) -> Result<(Self, Self), SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn conditionally_reverse<CS>(
cs: CS,
a: &Self,
b: &Self,
condition: &Boolean,
) -> Result<(Self, Self), SynthesisError>where
CS: ConstraintSystem<Scalar>,
Takes two allocated numbers (a, b) and returns (b, a) if the condition is true, and (a, b) otherwise.
pub fn get_value(&self) -> Option<Scalar>
pub fn get_variable(&self) -> Variable