Gadgets for allocating bits in the circuit and performing boolean logic.
Structs
- Allocated
Bit - Represents a variable in the constraint system which is guaranteed to be either zero or one.
Enums
- Boolean
- This is a boolean value which may be either a constant or
an interpretation of an
AllocatedBit.